/**
 *  Copyright (c) 1997-2013, tinygroup.org (luo_guo@live.cn).
 *
 *  Licensed under the GPL, Version 3.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *       http://www.gnu.org/licenses/gpl.html
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 * --------------------------------------------------------------------------
 *  版权 (c) 1997-2013, tinygroup.org (luo_guo@live.cn).
 *
 *  本开源软件遵循 GPL 3.0 协议;
 *  如果您不遵循此协议，则不被允许使用此文件。
 *  你可以从下面的地址获取完整的协议文本
 *
 *       http://www.gnu.org/licenses/gpl.html
 */
package org.tinygroup.chinese.fileresolver;

import org.tinygroup.chinese.PinYin;
import org.tinygroup.fileresolver.impl.AbstractFileProcessor;
import org.tinygroup.logger.LogLevel;
import org.tinygroup.springutil.SpringUtil;
import org.tinygroup.vfs.FileObject;

/**
 * 词库文件搜索器
 * 
 * @author renhui
 * 
 */
public class PinYinFileProcessor extends AbstractFileProcessor {

	// 词库文件后缀
	private static final String PIN_YIN_FILE = ".pinyin";
	// 默认文件字符集编码
	private static final String DEFAULT_ENCODE = "UTF-8";

	public boolean isMatch(FileObject fileObject) {
		return fileObject.getFileName().endsWith(PIN_YIN_FILE);
	}

	public void process() {

		PinYin pinYin = SpringUtil.getBean(PinYin.PINYIN_BEAN_NAME);
		for (FileObject fileObject : fileObjects) {
			logger.logMessage(LogLevel.INFO, "正在加载拼音文件[{0}]",
					fileObject.getAbsolutePath());
			pinYin.loadPinFile(fileObject.getInputStream(), DEFAULT_ENCODE);
			logger.logMessage(LogLevel.INFO, "加载拼音文件[{0}]结束",
					fileObject.getAbsolutePath());

		}
	}

}
