/**
 *  Copyright (c) 1997-2013, tinygroup.org (luo_guo@live.cn).
 *
 *  Licensed under the GPL, Version 3.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *       http://www.gnu.org/licenses/gpl.html
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 * --------------------------------------------------------------------------
 *  版权 (c) 1997-2013, tinygroup.org (luo_guo@live.cn).
 *
 *  本开源软件遵循 GPL 3.0 协议;
 *  如果您不遵循此协议，则不被允许使用此文件。
 *  你可以从下面的地址获取完整的协议文本
 *
 *       http://www.gnu.org/licenses/gpl.html
 */
package org.tinygroup.chinese.impl;

import java.io.BufferedReader;
import java.io.InputStream;
import java.io.InputStreamReader;
import java.util.ArrayList;
import java.util.List;

import org.tinygroup.binarytree.AVLTree;
import org.tinygroup.chinese.PinYin;
import org.tinygroup.chinese.exception.DictLoadRuntimeException;

public final class PinYinImpl implements PinYin {
	/**
	 * 用于存放字及其拼音
	 * 
	 * @author luoguo
	 * 
	 */

	private  AVLTree<CharWithPinYin> tree;
	

	public AVLTree<CharWithPinYin> getTree() {
		return tree;
	}


	public void setTree(AVLTree<CharWithPinYin> tree) {
		this.tree = tree;
	}

	public void loadPinFile(InputStream inputStream,
			String encode) {
		try {
			// 载入数据
			BufferedReader in = new BufferedReader(new InputStreamReader(inputStream,encode));
			String str;
			while ((str = in.readLine()) != null) {
				str = str.trim();
				if (str.length() > 0 && !str.startsWith("#")) {
					String[] s = str.split(" ");
					if (s.length == 2) {
						for (int i = 0; i < s[1].length(); i++) {
							addPinYin(s[1].charAt(i), s[0]);
						}
					}
				}
			}
			in.close();
		} catch (Exception e) {
			throw new DictLoadRuntimeException(e);
		}
	}


	private  void addPinYin(char charAt, String string) {
		CharWithPinYin py = new CharWithPinYin(charAt);
		CharWithPinYin p = tree.contains(py);
		if (p != null) {
			py = p;
		} else {
			tree.add(py);
		}
		py.addPinYin(string);
	}

	public PinYinImpl() {

	}

	public List<String> getPinYin(char c) {
		CharWithPinYin py = new CharWithPinYin(c);
		py = tree.contains(py);
		if (py != null) {
			return py.getPinyinVector();
		}
		return null;
	}

	@SuppressWarnings("unchecked")
	public List<String>[] getPinYin(char[] c) {
		List<String>[] r = new ArrayList[c.length];
		for (int i = 0; i < c.length; i++) {
			r[i] = getPinYin(c[i]);
		}
		return r;
	}

	public List<String> getPinYin(String str) {
		List<String> r = new ArrayList<String>();
		for (int i = 0; i < str.length(); i++) {
			r.add(getPinYin(str.charAt(i)).get(0));
		}
		return r;
	}

	public List<String> getPinYin(String str, String pinyin) {
		if (pinyin == null || pinyin.length() == 0) {
			return getPinYin(str);
		}
		List<String> result = new ArrayList<String>();
		for (int i = 0; i < str.length(); i++) {
			String nextChar = pinyin.substring(i, i + 1);
			result.add(getPinYin(str.charAt(i)).get(
					Integer.valueOf(nextChar) - 1));
		}
		return result;
	}
}

class CharWithPinYin implements Comparable<CharWithPinYin> {
	private Character c;
	private List<String> pinyinVector;

	public List<String> getPinyinVector() {
		return pinyinVector;
	}

	public void setPinyinVector(List<String> pinyinVector) {
		this.pinyinVector = pinyinVector;
	}

	public int compareTo(CharWithPinYin o) {
		return c.compareTo(o.c);
	}

	public void addPinYin(String string) {
		if (pinyinVector == null) {
			pinyinVector = new ArrayList<String>();
		}
		pinyinVector.add(string);
	}

	public CharWithPinYin(char c) {
		this.c = c;
	}
}